@@ -37,7 +37,7 @@ log = logging.getLogger(__name__)
 
 def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
            short_urls=False, major=None, only=None, at=None,
-           having_asset=None, exclude=None):
+           having_asset=None, exclude=None, even=False):
     """Find the latest release version for a project.
 
     Args:
@@ -57,6 +57,7 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
         having_asset (Union[str, bool]): Only consider releases with the given asset.
                                          Pass `True` for any asset
         exclude (str): Only consider releases NOT containing this text/regular expression.
+        even (bool): Consider as stable only releases with even minor component, e.g. 1.2.3
 
     Examples:
         Find the latest version of Mautic, it is OK to consider betas.
@@ -94,7 +95,7 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
 
     if repo.endswith('.spec'):
         # repo is specified inside the .spec file
-        # github repo is resolved via %{upstream_github} + %{name}/%{upstream_name}
+        # GitHub repo is resolved via %{upstream_github} + %{name}/%{upstream_name}
         # no upstream_github global means that the spec was not prepared for lastversion
         # optional: use of spec_tag macros if the source is from GitHub. in edge cases we check
         # new version via GitHub, but prepared sources are elsewhere
@@ -105,23 +106,23 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
             current_version = None
             spec_repo = None
             spec_url = None
-            for l in f.readlines():
-                if l.startswith('%global lastversion_repo'):
-                    spec_repo = l.split(' ')[2].strip()
-                elif l.startswith('%global upstream_github'):
-                    upstream_github = l.split(' ')[2].strip()
-                elif l.startswith('%global upstream_name'):
-                    upstream_name = l.split(' ')[2].strip()
-                elif l.startswith('Name:'):
-                    name = l.split('Name:')[1].strip()
-                elif l.startswith('URL:'):
-                    spec_url = l.split('URL:')[1].strip()
-                elif l.startswith('%global upstream_version '):
-                    current_version = l.split(' ')[2].strip()
+            for line in f.readlines():
+                if line.startswith('%global lastversion_repo'):
+                    spec_repo = line.split(' ')[2].strip()
+                elif line.startswith('%global upstream_github'):
+                    upstream_github = line.split(' ')[2].strip()
+                elif line.startswith('%global upstream_name'):
+                    upstream_name = line.split(' ')[2].strip()
+                elif line.startswith('Name:'):
+                    name = line.split('Name:')[1].strip()
+                elif line.startswith('URL:'):
+                    spec_url = line.split('URL:')[1].strip()
+                elif line.startswith('%global upstream_version '):
+                    current_version = line.split(' ')[2].strip()
                     # influences %spec_tag to use %upstream_version instead of %version
                     repo_data['module_of'] = True
-                elif l.startswith('Version:') and not current_version:
-                    current_version = l.split('Version:')[1].strip()
+                elif line.startswith('Version:') and not current_version:
+                    current_version = line.split('Version:')[1].strip()
             if spec_url:
                 spec_host = urlparse(spec_url).hostname
                 if spec_host in ['github.com'] and not upstream_github and not spec_repo:
@@ -157,6 +158,7 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=None,
         project.set_only(only)
         project.set_exclude(exclude)
         project.set_having_asset(having_asset)
+        project.set_even(even)
         release = project.get_latest(pre_ok=pre_ok, major=major)
 
         # bail out, found nothing that looks like a release
@@ -389,7 +391,7 @@ def main():
     # how / which data of last release we want to present
     # assets will give download urls for assets if available and sources archive otherwise
     # sources will give download urls for sources always
-    # json always includes "version", "tag_name" etc + whichever json data was
+    # json always includes "version", "tag_name" etc. + whichever json data was
     # used to satisfy lastversion
     parser.add_argument('--format',
                         choices=['version', 'assets', 'source', 'json', 'tag'],
@@ -416,6 +418,8 @@ def main():
                         nargs='?', const=True)
     parser.add_argument('-su', '--shorter-urls', dest='shorter_urls', action='store_true',
                         help='A tiny bit shorter URLs produced')
+    parser.add_argument('--even', dest='even', action='store_true',
+                        help='Only even versions like 1.[2].x, or 3.[6].x are considered as stable')
     parser.add_argument('--at', dest='at',
                         help='If the repo argument is one word, specifies where to look up the '
                              'project. The default is via internal lookup or GitHub Search',
@@ -426,7 +430,7 @@ def main():
     parser.set_defaults(validate=True, verbose=False, format='version',
                         pre=False, assets=False, newer_than=False, filter=False,
                         shorter_urls=False, major=None, assumeyes=False, at=None,
-                        having_asset=None)
+                        having_asset=None, even=False)
     args = parser.parse_args()
 
     if args.repo == "self":
@@ -530,7 +534,7 @@ def main():
     try:
         res = latest(args.repo, args.format, args.pre, args.filter,
                      args.shorter_urls, args.major, args.only, args.at,
-                     having_asset=args.having_asset, exclude=args.exclude)
+                     having_asset=args.having_asset, exclude=args.exclude, even=args.even)
     except (ApiCredentialsError, BadProjectError) as error:
         log.critical(str(error))
         if isinstance(error, ApiCredentialsError) and "GITHUB_API_TOKEN" not in os.environ and \
